==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appsync/kotlin/inputs/DataSourceEventBridgeConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appsync.kotlin.inputs

import com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventBusArn ARN for the EventBridge bus.
 */
public data class DataSourceEventBridgeConfigArgs(
    public val eventBusArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs> {
    override fun toJava(): com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs =
        com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs.builder()
            .eventBusArn(eventBusArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceEventBridgeConfigArgs].
 */
@PulumiTagMarker
public class DataSourceEventBridgeConfigArgsBuilder internal constructor() {
    private var eventBusArn: Output<String>? = null

    /**
     * @param value ARN for the EventBridge bus.
     */
    @JvmName("akjejlemykavfeuj")
    public suspend fun eventBusArn(`value`: Output<String>) {
        this.eventBusArn = value
    }

    /**
     * @param value ARN for the EventBridge bus.
     */
    @JvmName("ltnlxolfmblmtgox")
    public suspend fun eventBusArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventBusArn = mapped
    }

    internal fun build(): DataSourceEventBridgeConfigArgs = DataSourceEventBridgeConfigArgs(
        eventBusArn = eventBusArn ?: throw PulumiNullFieldException("eventBusArn"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appsync/kotlin/inputs/DataSourceEventBridgeConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appsync.kotlin.inputs

import com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventBusArn ARN for the EventBridge bus.
 */
public data class DataSourceEventBridgeConfigArgs(
    public val eventBusArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs> {
    override fun toJava(): com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs =
        com.pulumi.aws.appsync.inputs.DataSourceEventBridgeConfigArgs.builder()
            .eventBusArn(eventBusArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceEventBridgeConfigArgs].
 */
@PulumiTagMarker
public class DataSourceEventBridgeConfigArgsBuilder internal constructor() {
    private var eventBusArn: Output<String>? = null

    /**
     * @param value ARN for the EventBridge bus.
     */
    @JvmName("uxumrlqkmmdtjxak")
    public suspend fun eventBusArn(`value`: Output<String>) {
        this.eventBusArn = value
    }

    /**
     * @param value ARN for the EventBridge bus.
     */
    @JvmName("xqghvifdgcoaktie")
    public suspend fun eventBusArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventBusArn = mapped
    }

    internal fun build(): DataSourceEventBridgeConfigArgs = DataSourceEventBridgeConfigArgs(
        eventBusArn = eventBusArn ?: throw PulumiNullFieldException("eventBusArn"),
    )
}
